/*
 * Copyright (C) 2013 Google Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Modified by Octoshape 2015
 */

package com.google.sample.cast.refplayer.browser;

import android.content.Context;
import android.net.Uri;
import android.support.v4.content.AsyncTaskLoader;

import com.google.android.gms.cast.MediaInfo;
import com.google.android.gms.cast.MediaMetadata;
import com.google.android.gms.common.images.WebImage;

import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import octoshape.android.stream.StreamManager;

/**
 *
 */
class StreamItemLoader extends AsyncTaskLoader<List<MediaInfo>> {

    private static final String OCTOLINK_NBA = "octoshape://streams.octoshape.net/demo/live/nba/abr";
    private static final String OCTOLINK_NASCAR = "octoshape://streams.octoshape.net/demo/live/nascar/abr";
    private static final String OCTOLINK_PGA = "octoshape://streams.octoshape.net/demo/live/pga/abr";
    private static final String OCTO_VOD = "octoshape://streams.octoshape.net/test/WayBackHome720?segmentlength=5s";
    private static final String OCTO_VOD_SINTEL = "octoshape://ond.octoshape.com/demoplayer/mobile/sintel/sintel_750_640x272_slow_film.mp4";

    /**
     * Stores away the application context associated with context.
     * Since Loaders can be used across multiple activities it's dangerous to
     * store the context directly; always use {@link #getContext()} to retrieve
     * the Loader's Context, don't use the constructor argument directly.
     * The Context returned by {@link #getContext} is safe to use across
     * Activity instances.
     *
     * @param context used to retrieve the application context.
     */
    public StreamItemLoader(Context context) {
        super(context);
    }

    @Override
    public List<MediaInfo> loadInBackground() {
        ArrayList<MediaInfo> result = new ArrayList<MediaInfo>();

        result.add(makeOne(OCTOLINK_NASCAR, "NASCAR"));
        result.add(makeOne(OCTOLINK_NBA, "NBA"));
        result.add(makeOne(OCTOLINK_PGA, "PGA"));
        result.add(makeOne(OCTO_VOD, "Way back home"));
        result.add(makeOne(OCTO_VOD_SINTEL, "SINTEL"));

        return result;
    }

    @Override
    protected void onStartLoading() {
        super.onStartLoading();
        forceLoad();
    }

    /**
     * Handles a request to stop the Loader.
     */
    @Override
    protected void onStopLoading() {
        // Attempt to cancel the current load task if possible.
        cancelLoad();
    }

    private MediaInfo makeOne(String stream, String title) {
        MediaMetadata movieMetadata = new MediaMetadata(MediaMetadata.MEDIA_TYPE_MOVIE);

        movieMetadata.putString(MediaMetadata.KEY_SUBTITLE, "Fusce id nisi turpis. Praesent viverra bibendum semper. Donec tristique, orci sed semper lacinia, quam erat rhoncus massa, non congue tellus est quis tellus. Sed mollis orci venenatis quam scelerisque accumsan. Curabitur a massa sit amet mi accumsan mollis sed et magna. Vivamus sed aliquam risus. Nulla eget dolor in elit facilisis mattis. Ut aliquet luctus lacus. Phasellus nec commodo erat. Praesent tempus id lectus ac scelerisque. Maecenas pretium cursus lectus id volutpat.");
        movieMetadata.putString(MediaMetadata.KEY_TITLE, title);
        movieMetadata.putString(MediaMetadata.KEY_STUDIO, "Blender Foundation");

        HashMap<String, String> customData = new HashMap<String, String>();
        customData.put(StreamManager.STREAM_ADDR, stream);

        // First image is shown in the client app, when the user is browsing the streams
        // Failing to provide a valid address will result in the app loading a default image, with the octoshape logo
        movieMetadata.addImage(new WebImage(Uri.parse("http://www.octoshape.com/wp-content/themes/Octoshape_Radi8/images/site_footer_logo.png")));
        // Second image is used as artwork for the art cover, when casting
        movieMetadata.addImage(new WebImage(Uri.parse("http://i.i.cbsi.com/cnwk.1d/i/tim/2012/10/18/fmimg4497667357722720781.jpg")));

        String contentType;
        if (stream.endsWith("m3u8"))
            contentType = "application/x-mpegURL";
        else
            contentType = "video/mp4";

        MediaInfo mediaInfo = new MediaInfo.Builder(stream)
                .setContentType(contentType)
                .setStreamType(MediaInfo.STREAM_TYPE_BUFFERED)
                .setMetadata(movieMetadata)
                .setCustomData(new JSONObject(customData))
                .build();

        return mediaInfo;
    }

}